@@ -17,12 +17,13 @@ from boto3.session import Session
 
 
 __author__ = 'Amazon Web Services'
-__version__ = '1.1.0'
+__version__ = '1.5.35'
 
 
 # The default Boto3 session; autoloaded when needed.
 DEFAULT_SESSION = None
 
+
 def setup_default_session(**kwargs):
     """
     Set up a default session, passing through any parameters to the session
@@ -32,6 +33,7 @@ def setup_default_session(**kwargs):
     global DEFAULT_SESSION
     DEFAULT_SESSION = Session(**kwargs)
 
+
 def set_stream_logger(name='boto3', level=logging.DEBUG, format_string=None):
     """
     Add a stream handler for the given name and level to the logging module.
@@ -58,11 +60,12 @@ def set_stream_logger(name='boto3', level=logging.DEBUG, format_string=None):
     handler.setFormatter(formatter)
     logger.addHandler(handler)
 
+
 def _get_default_session():
     """
     Get the default session, creating one if needed.
 
-    :rtype: :py:class:`~boto3.session.Sesssion`
+    :rtype: :py:class:`~boto3.session.Session`
     :return: The default session
     """
     if DEFAULT_SESSION is None:
@@ -70,6 +73,7 @@ def _get_default_session():
 
     return DEFAULT_SESSION
 
+
 def client(*args, **kwargs):
     """
     Create a low-level service client by name using the default session.
@@ -78,6 +82,7 @@ def client(*args, **kwargs):
     """
     return _get_default_session().client(*args, **kwargs)
 
+
 def resource(*args, **kwargs):
     """
     Create a resource service client by name using the default session.
@@ -86,6 +91,7 @@ def resource(*args, **kwargs):
     """
     return _get_default_session().resource(*args, **kwargs)
 
+
 # Set up logging to ``/dev/null`` like a library is supposed to.
 # http://docs.python.org/3.3/howto/logging.html#configuring-logging-for-a-library
 class NullHandler(logging.Handler):
